package com.hippo.a7zip;

import java.io.File;
import java.io.RandomAccessFile;

public class FileSeekableOutputStream extends SeekableOutputStream {
    private final RandomAccessFile file;

    public FileSeekableOutputStream(String str) {
        this(new File(str));
    }

    @Override // java.io.OutputStream, java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        this.file.close();
    }

    @Override // com.hippo.a7zip.SeekableOutputStream
    public void seek(long j) {
        this.file.seek(j);
    }

    @Override // com.hippo.a7zip.SeekableOutputStream
    public long size() {
        return this.file.length();
    }

    @Override // com.hippo.a7zip.SeekableOutputStream
    public long tell() {
        return this.file.getFilePointer();
    }

    @Override // com.hippo.a7zip.SeekableOutputStream
    public void truncate(long j) {
        this.file.setLength(j);
    }

    @Override // java.io.OutputStream
    public void write(int i) {
        this.file.write(i);
    }

    public FileSeekableOutputStream(File file2) {
        this(new RandomAccessFile(file2, "rw"));
    }

    @Override // java.io.OutputStream
    public void write(byte[] bArr) {
        this.file.write(bArr);
    }

    public FileSeekableOutputStream(RandomAccessFile randomAccessFile) {
        this.file = randomAccessFile;
    }

    @Override // java.io.OutputStream
    public void write(byte[] bArr, int i, int i2) {
        this.file.write(bArr, i, i2);
    }
}
