package com.hippo.image;

import android.graphics.Canvas;
import android.graphics.ColorFilter;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.drawable.Animatable;
import android.graphics.drawable.Drawable;
import com.hippo.image.ImageBitmap;

public class ImageDrawable extends Drawable implements Animatable, ImageBitmap.Callback {
    private final ImageBitmap mImageBitmap;
    private final Paint mPaint;

    public ImageDrawable(ImageBitmap imageBitmap) {
        if (imageBitmap.obtain()) {
            this.mImageBitmap = imageBitmap;
            this.mPaint = new Paint(2);
            imageBitmap.addCallback(this);
            return;
        }
        throw new RecycledException();
    }

    public void draw(Canvas canvas) {
        this.mImageBitmap.draw(canvas, (Rect) null, getBounds(), this.mPaint);
    }

    public int getIntrinsicHeight() {
        return this.mImageBitmap.getHeight();
    }

    public int getIntrinsicWidth() {
        return this.mImageBitmap.getWidth();
    }

    public int getOpacity() {
        return this.mImageBitmap.isOpaque() ? -1 : 0;
    }

    @Override // com.hippo.image.ImageBitmap.Callback
    public void invalidateImage(ImageBitmap imageBitmap) {
        invalidateSelf();
    }

    public boolean isRunning() {
        return this.mImageBitmap.isRunning();
    }

    public void recycle() {
        this.mImageBitmap.removeCallback(this);
        this.mImageBitmap.release();
    }

    public void setAlpha(int i) {
        this.mPaint.setAlpha(i);
    }

    public void setColorFilter(ColorFilter colorFilter) {
        this.mPaint.setColorFilter(colorFilter);
    }

    public void start() {
        this.mImageBitmap.start();
    }

    public void stop() {
        this.mImageBitmap.stop();
    }
}
